meshingComponent1 = None
study1 = None
physicsDefinitionComponent1 = None
resultsEvaluationComponent1 = None
solvePhysicsComponent1 = None
physicsRegion1 = None
vectorResult1 = None
singleValueResult1 = None
results1 = None
materialAssignment1 = None
currentStep = None
clr.AddReference("Ans.UI")

def getSelectionSetsForProject():
    context = __scriptingEngine__.CommandContext
    project = context.Project
    containers = project.GetContainers()
    dataEntity = "SelectionSet"

    for container in containers:
        if container.Name == "Study":
            try:
                lockObject = context.ContainerReadLock(container)
                dataReferences = project.GetDataReferencesByType(container, dataEntity)           
            finally:
                lockObject.Dispose()
            break
    return dataReferences

def initLocations(step):
    list = getSelectionSetsForProject()
    propIn = step.Properties["Inlet/InletLocation"]
    propIn.Options.Clear()
    propOut = step.Properties["Outlet/OutletLocation"]
    propOut.Options.Clear()
    for sel in list:
        ExtAPI.Log.WriteMessage("OPTION: "+sel.DisplayText)
        propIn.Options.Add(sel.DisplayText)
        propOut.Options.Add(sel.DisplayText)
    comp = step.UserInterface.GetComponent("Properties")
    comp.UpdateData()
    comp.Refresh()

def isValid(step, property):
    if property.Value == step.Properties["Inlet/InletLocation"].Value:
        ExtAPI.Log.WriteWarning("Inlet and Outlet locations must be different.")
        return False
    return True

def importGeometry(step):
    global  meshingComponent1, study1, results1, vectorResult1, singleValueResult1, physicsDefinitionComponent1, resultsEvaluationComponent1, solvePhysicsComponent1, physicsRegion1, materialAssignment1
    with Transaction():
        system1 = GetSystem(Name="Study")
        physicsDefinitionComponent1 = Study.CreateTask( Type="Physics Definition", System=system1)
        study1 = system1.GetContainer(ComponentName="Study")
        physicsDefinition1 = physicsDefinitionComponent1.GetTaskObject()
        physicsRegion1 = study1.CreateEntity( Type="PhysicsRegion", Association=physicsDefinition1)
        solverSettings1 = study1.CreateEntity( Type="SolverSettings", Association=physicsDefinition1)
        solvePhysicsComponent1 = Study.CreateTask( Type="Solve Physics", System=system1, Input=physicsDefinitionComponent1)
        solvePhysicsComponent1.Refresh()
        resultsEvaluationComponent1 = Study.CreateTask( Type="Results Evaluation", System=system1, Input=solvePhysicsComponent1)
        resultsEvaluationComponent1.Refresh()
        physicsDefinition1.CalculationType = "Static"
        physicsRegion1.PhysicsType = "Fluid"
        physicsRegion1.Location = "AllBodies()"
        materialAssignment1 = study1.CreateEntity( Type="MaterialAssignment", Association=physicsDefinition1)
        material1 = study1.CreateEntity( Type="Material", Association=physicsDefinition1)
        material1.ImportEngineeringData(Name="Air")
        materialAssignment1.Material = material1

        materialAssignment1.Location = [physicsRegion1]
        results1 = resultsEvaluationComponent1.GetTaskObject()
        vectorResult1 = study1.CreateEntity( Type="VectorResult", Association=results1)
        vectorResult1.Variable = "Velocity"
        vectorResult1.DisplayText = "Velocity"
        transcript1 = study1.CreateEntity( Type="Transcript", Association=physicsDefinition1)
        transcript1.DisplayText = "Fluid Flow Output  1"
        physicsSolutionGroup1 = Study.CreateGroup(Name="Physics Solution")
        physicsSolutionGroup1.Add(Component=physicsDefinitionComponent1)
        physicsSolutionGroup1.Add(Component=solvePhysicsComponent1)
        meshingComponent1 = Study.CreateTask( Type="Meshing", System=system1, Output=physicsDefinitionComponent1)
        physicsDefinitionComponent1.Refresh()
        solvePhysicsComponent1.Refresh()
        resultsEvaluationComponent1.Refresh()
        importComponent1 = Study.CreateTask( Type="Import", System=system1, Output=meshingComponent1)
        meshingComponent1.Refresh()
        physicsDefinitionComponent1.Refresh()
        solvePhysicsComponent1.Refresh()
        resultsEvaluationComponent1.Refresh()
        import1 = importComponent1.GetTaskObject()
        geometryImportSource1 = import1.AddGeometryImportSourceOperation()
        geometryImportSource1.FilePath = step.Properties["geometryfile"].Value
        importComponent1.Update(AllDependencies=True)
        meshingComponent1.Refresh()
        physicsDefinitionComponent1.Refresh()
        solvePhysicsComponent1.Refresh()
        resultsEvaluationComponent1.Refresh()

def refineMesh(step):
    global meshingComponent1, study1, results1, vectorResult1, physicsDefinitionComponent1, singleValueResult1, resultsEvaluationComponent1, solvePhysicsComponent1, physicsRegion1
    meshing1 = meshingComponent1.GetTaskObject()
    meshing1.MeshResolution = step.Properties["MeshResolution"].Value

def setup(step):
    global meshingComponent1, study1, results1, vectorResult1, physicsDefinitionComponent1, singleValueResult1, resultsEvaluationComponent1, solvePhysicsComponent1, physicsRegion1
    with Transaction():
        meshing1 = meshingComponent1.GetTaskObject()
        meshControlLocalInflation1 = study1.CreateEntity( Type="MeshControlLocalInflation", Association=meshing1)
        meshing1.EngineeringIntent = "FluidFlow"
        AddSourceToComponentInSystem( SourceComponent=physicsDefinitionComponent1, TargetComponent=resultsEvaluationComponent1)
        resultsEvaluationComponent1.Refresh()
    #meshControlLocalInflation1.Location = ["FACE8", "FACE2", "FACE6"]
    Study.Delete(Items=[meshControlLocalInflation1])
    with Transaction():
        meshingComponent1.Update(AllDependencies=True)
        physicsDefinitionComponent1.Refresh()
        solvePhysicsComponent1.Refresh()
        resultsEvaluationComponent1.Refresh()
        
    with Transaction():
        inletBoundary1 = study1.CreateEntity( Type="InletBoundary", Association=physicsRegion1)

        inlet_location = step.Properties["Inlet/InletLocation"].Value
        ExtAPI.Log.WriteMessage("my inlet location property value is : " + inlet_location)
        inlet_selection_set = None
        selection_sets = getSelectionSetsForProject()
        for selection_set in selection_sets:
            if selection_set.DisplayText == inlet_location:
                inlet_selection_set = selection_set
        if inlet_selection_set == None :
            ExtAPI.Log.WriteMessage("inlet selection set does not exist")

        inletBoundary1.Location = [inlet_selection_set]

        inletBoundary1.Flow.Velocity.Magnitude = step.Properties["Inlet/Velocity"].DisplayString

        outletBoundary1 = study1.CreateEntity( Type="OutletBoundary", Association=physicsRegion1)

        outlet_location = step.Properties["Outlet/OutletLocation"].Value

        outlet_selection_set = None
        selection_sets = getSelectionSetsForProject()
        for selection_set in selection_sets:
            if selection_set.DisplayText == outlet_location:
                outlet_selection_set = selection_set
        if outlet_selection_set == None :
            ExtAPI.Log.WriteMessage("outlets selection set does not exist")

        outletBoundary1.Location = [outlet_selection_set]
        outletBoundary1.Flow.Pressure.GaugeStaticPressure = step.Properties["Outlet/GaugePressure"].DisplayString

        wallBoundary1 = study1.CreateEntity( Type="WallBoundary", Association=physicsRegion1)

        # Creation of the pressure loss expression.
        singleValueResult1 = study1.CreateEntity( Type="SingleValueResult", Association=results1)
        singleValueResult1.Method = "UserDefinedExpressionMethod"
        singleValueResult1.Expression = "Average(Pressure, GetBoundary('@Inlet 1'), Weight='Area') - Average(Pressure, GetBoundary('@Outlet 1'), Weight='Area')"

    with Transaction():
        physicsDefinitionComponent1.Update(AllDependencies=True)
        solvePhysicsComponent1.Update(AllDependencies=True)
        resultsEvaluationComponent1.Refresh()
        resultsEvaluationComponent1.Refresh()
    resultsEvaluationComponent1.Update(AllDependencies=True)

    vectorResult1.Legend.Coloring = "Banded"
    vectorResult1.Legend.NumberOfColors = "10"
    vectorResult1.Distribution = "Mesh"
    vectorResult1.Evaluate()
    maximum_velocity = vectorResult1.Summary.Max
    step.NextStep.Properties["MaximumVelocity"].Value = maximum_velocity.ToString()
    step.NextStep.Properties["PressureLoss"].Value = singleValueResult1.Value.ToString()

def solve(step):
    global meshingComponent1, study1, results1, vectorResult1, physicsDefinitionComponent1, singleValueResult1, resultsEvaluationComponent1, solvePhysicsComponent1, physicsRegion1
    with Transaction():
        physicsDefinitionComponent1.Update(AllDependencies=True)
        solvePhysicsComponent1.Update(AllDependencies=True)
        resultsEvaluationComponent1.Refresh()
        resultsEvaluationComponent1.Refresh()
    resultsEvaluationComponent1.Update(AllDependencies=True)

    vectorResult1.Legend.Coloring = "Banded"
    vectorResult1.Legend.NumberOfColors = "10"
    vectorResult1.Distribution = "Mesh"
    vectorResult1.Evaluate()
    maximum_velocity = vectorResult1.Summary.Max
    step.NextStep.Properties["MaximumVelocity"].Value = maximum_velocity.ToString()
    step.NextStep.Properties["PressureLoss"].Value = singleValueResult1.Value.ToString()